import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.net.Socket;

/**
 * Ein Empfangsprozess fr den Spielclient.
 * 
 * @author Bernd Gramlich
 * @version 2014-12-31
 */
public class ClientEmpfangsProzess implements Runnable
{
    private Socket meinSocket;
    private Spiel meinSpiel;

    /**
     * Konstruktor.
     * Verbinde Dich an den angegebenen Socket und starte ein
     * neues Spiel.
     */
    public ClientEmpfangsProzess (Socket s, ClientSendeProzess e)
    { 
        meinSocket = s;
        meinSpiel  = new Spiel ();

        Leinwand.gibLeinwand ().gibFenster ().addKeyListener (e);
        Leinwand.gibLeinwand ().gibZeichenflaeche ().addMouseListener (e);
    }

    /**
     * Ablaufplan.
     * Lies und echoe vom Server, bis er "Bye." sendet.
     */
    public void run ()
    { 
        try 
        {
            /*
             * Datenstrom vom Server.
             */
            BufferedReader liesVomServer   = new BufferedReader (new InputStreamReader (meinSocket.getInputStream ()));

            /*
             * Ausgabezeile.
             */
            String serverZeile;

            /*
             * Chatte, solange der Server sendet und solange er sich
             * nicht verabschiedet.
             */  
            serverZeile = liesVomServer.readLine ();

            while (serverZeile != null && !serverZeile.equals ("Bye."))
            {
                System.out.println (serverZeile);

                if (serverZeile.equals ("Playing."))
                {
                    meinSpiel.fangeAn ();
                }
                else if (serverZeile.startsWith ("moved "))
                {
                    try
                    {
                        int spaltennummer = Integer.parseInt (serverZeile.substring (6));

                        meinSpiel.wirfNaechsteFarbeEin (spaltennummer);
                    }
                    catch (Exception fehler)
                    {
                        /*
                         * Wenn sich jemand den Nick "moved" gibt, knnen dessen Lebenszeichen
                         * flschlicherweise als Spielzge interpretiert werden. Das fhrt zu
                         * Fehlermeldungen, die wir einfach ignorieren.
                         */
                    }
                }
                else if (serverZeile.equals ("Done."))
                {
                    meinSpiel.hoereAuf ();
                }

                serverZeile = liesVomServer.readLine ();
            }

            /*
             * Schliee den Datenstrom und den Socket.
             */
            liesVomServer.close ();
            meinSocket.close ();
        }
        catch (IOException fehler) 
        {
            System.err.println ("Keine Verbindung beim Empfangen.");
        }
    }
}