import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.IOException;
import java.net.Socket;

/**
 * Ein Sendeprozess fr den Spielclient.
 * 
 * @author Bernd Gramlich
 * @version 2015-05-11
 */
public class ClientSendeProzess implements Runnable, KeyListener, MouseListener
{
    private Socket meinSocket;
    private PrintWriter gibAnServer;
    private BufferedReader liesVonTastatur;

    /**
     * Konstruktor.
     * Verbinde Dich an den angegebenen Socket.
     */
    public ClientSendeProzess (Socket s)
    { 
        meinSocket = s;
    }

    /**
     * Ablaufplan.
     * Sende die Tastatureingabe an den Server, bis sie "quit" lautet.
     */
    public void run ()
    { 
        try 
        {
            /*
             * Datenstrme an den Server und von der Tastatur.
             */
            gibAnServer     = new PrintWriter (meinSocket.getOutputStream (), true);
            liesVonTastatur = new BufferedReader (new InputStreamReader (System.in));

            /*
             * Ein- und Ausgabezeile.
             */
            String tastaturZeile;

            /*
             * Chatte, solange die Benutzerin nicht "quit" eingibt.
             */
            do
            {
                tastaturZeile = liesVonTastatur.readLine (); 

                if (tastaturZeile != null)
                {
                    gibAnServer.println (tastaturZeile);
                }
            }
            while (!tastaturZeile.equals ("quit"));           

            /*
             * Schliee die Datenstrme.
             */
            liesVonTastatur.close ();
        }
        catch (IOException fehler) 
        {
            System.err.println ("Keine Verbindung beim Senden.");
        }
    }

    /**
     * Reagiere nicht auf das Drcken einer Taste.
     */
    public void keyPressed (KeyEvent taste)
    {   
    }

    /**
     * Reagiere auf das Tippen einer darstellbaren Taste.
     */
    public void keyTyped (KeyEvent taste)
    {
        char zeichen = taste.getKeyChar ();

        try
        {
            switch (zeichen)
            {
                case 'r':
                gibAnServer.println ("resign");
                break;
                
                case 'd':
                gibAnServer.println ("done");
                break;

                default:
                gibAnServer.println ("move " + zeichen);
                break;
            }
        }
        catch (Exception fehler) 
        {
            System.err.println ("Keine Verbindung beim Senden.");
        }
    }

    /**
     * Reagiere nicht auf das Loslassen einer Taste.
     */
    public void keyReleased (KeyEvent taste)
    {
    }

    /**
     * Reagiere nicht auf das Druecken der Maustaste.
     */
    public void mousePressed (MouseEvent ereignis)
    {
    }

    /**
     * Reagiere auf das Loslassen des Mausknopfes.
     */
    public void mouseReleased (MouseEvent ereignis)
    {
        System.out.println ("Maus an (" + ereignis.getX () + "|"
           + ereignis.getY () + ") losgelassen.");
    }

    /**
     * Reagiere nicht auf das Klicken mit der Maus.
     */
    public void mouseClicked (MouseEvent ereignis)
    {
    }

    /**
     * Reagiere nicht auf das Verlassen der Leinwand mit der Maus.
     */
    public void mouseExited (MouseEvent ereignis)
    {
    }

    /**
     * Reagiere nicht auf das Betreten der Leinwand mit der Maus.
     */
    public void mouseEntered (MouseEvent ereignis)
    {
    }
}